Flarch class

Constructors

Flarch()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printUsage() → void
printVersion() → void
run(List<String> arguments) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

gold String
final
skyBlue String
final
successGreen String
final
white String
final

Static Methods

rgb(int r, int g, int b, {bool bold = false}) String

Constants

reset → const String